@@ -3,7 +3,7 @@ package Class::Trait;
 use strict;
 use warnings;
 
-our $VERSION = '0.20';
+our $VERSION = '0.21';
 
 use overload   ();
 use File::Spec ();
@@ -89,6 +89,9 @@ my $DOES = sub {
     }
     if (@_) {
         my $trait_name = shift;
+
+        return 1 if $class eq $trait_name;   # everything can do itself
+
         if ( exists $PACKAGE_DOES{$class}{$trait_name} ) {
             return 1;
         }
@@ -651,7 +654,7 @@ sub _load_trait {
 
     # initialize our trait configuration
     my $trait_config = Class::Trait::Config->new();
-    $trait_config->name = $trait;
+    $trait_config->name($trait);
 
     _get_trait_requirements($trait_config);
     _get_trait_methods($trait_config);
@@ -703,8 +706,8 @@ sub _override_trait {
 
     # create a new trait config to represent the combined traits
     my $trait_config = Class::Trait::Config->new();
-    $trait_config->name       = $overriding_trait->name;
-    $trait_config->sub_traits = [
+    $trait_config->name( $overriding_trait->name );
+    $trait_config->sub_traits([
 
         # if we have a composite trait we dont want to include the name here
         # as it is actually defined better in the sub_traits field, but if we
@@ -712,19 +715,19 @@ sub _override_trait {
 
         ( ( COMPOSITE() eq $trait->name ) ? () : $trait->name ),
         @{ $trait->sub_traits }
-    ];
+    ]);
 
     # let the overriding trait override the methods in the regular trait
-    $trait_config->methods =
-      { %{ $trait->methods }, %{ $overriding_trait->methods } };
+    $trait_config->methods(
+      { %{ $trait->methods }, %{ $overriding_trait->methods } });
 
     # the same for overloads
-    $trait_config->overloads =
-      { %{ $trait->overloads }, %{ $overriding_trait->overloads } };
+    $trait_config->overloads( 
+      { %{ $trait->overloads }, %{ $overriding_trait->overloads } });
 
     # now combine the requirements as well
-    $trait_config->requirements =
-      { %{ $trait->requirements }, %{ $overriding_trait->requirements } };
+    $trait_config->requirements(
+      { %{ $trait->requirements }, %{ $overriding_trait->requirements } });
 
     if (DEBUG) {
         debug "? checking for requirement fufillment";
@@ -803,7 +806,7 @@ sub _get_trait_requirements {
     # get any requirements in the trait and turn it into a hash so we can
     # track stuff easier
 
-    $trait_config->requirements = { map { $_ => 1 } @{"${trait}::REQUIRES"} }
+    $trait_config->requirements( { map { $_ => 1 } @{"${trait}::REQUIRES"} } )
       if defined @{"${trait}::"}{REQUIRES};
 }
 
@@ -831,7 +834,7 @@ sub _get_trait_methods {
         }
         $implementation_for{$_} = $method;
     }
-    $trait_config->methods = \%implementation_for;
+    $trait_config->methods(\%implementation_for);
 }
 
 sub _get_trait_overloads {
@@ -847,7 +850,7 @@ sub _get_trait_overloads {
     debug "< getting overloads for ${trait}" if DEBUG;
 
     # get the overload parameter hash
-    $trait_config->overloads = { %{"${trait}::OVERLOADS"} }
+    $trait_config->overloads({ %{"${trait}::OVERLOADS"} })
       if defined %{"${trait}::OVERLOADS"};
 }
 
@@ -975,7 +978,7 @@ sub _sum_traits {
     my $trait_config = Class::Trait::Config->new();
 
     # we are making a composite trait, so lets call it as such
-    $trait_config->name = COMPOSITE;
+    $trait_config->name(COMPOSITE);
 
     $debug_indent++ if DEBUG;
 
@@ -1477,8 +1480,21 @@ the object implements the trait, and false (0) otherwise.
 
   $my_object_with_traits->does('TPrintable');
 
-Calling C<does> without arguments will return all traits an ojbect does.
+Calling C<does> without arguments will return all traits an object does.
 
+As of version C<0.21>, this method will now return true for the class
+composing the traits.
+
+ package Customer;
+
+ use Class::Trait qw< TSerializable >;
+
+ if ( Customer->does('TSerializable') ) { # always true
+    ...
+ }
+ if ( Customer->does('Customer') ) { # always true.  Previously false.
+    ...
+ }
 =item * B<is>
 
 Class::Trait used to export this method to any object which uses traits, but
